<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;

class SubCategoriesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $rows = Category::where('parent_id', $request->get('id'))->latest()->get();
        $id = $request->get('id');
        return view('admin.subcategories.index', compact('rows', 'id'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        $category = Category::find($request->get('id'));
        return view('admin.subcategories.create', compact('category'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required'
        ]);
        $subcategories = new Category();
        $subcategories['name->ar'] = $request['name_ar'];
        $subcategories['name->en'] = $request['name_en'];
        $subcategories['parent_id'] = $request['parent_id'];
        $subcategories->save();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('subcategories.index', 'id=' . $request['parent_id']);

    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Category::find($id);
        return view('admin.subcategories.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required'
        ]);
        $subcategories = Category::find($id);
        $subcategories['name->ar'] = $request['name_ar'];
        $subcategories['name->en'] = $request['name_en'];

        $subcategories->update();
        toast('تمت العملية بنجاح', 'success');
        return redirect()->route('subcategories.index', 'id=' . $subcategories->parent_id);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Category::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
