<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CategoriesResource;
use App\Http\Resources\NotificationResource;
use App\Http\Resources\ProductResource;
use App\Models\Category;
use App\Models\ContactUs;
use App\Models\Country;
use App\Models\Notification;
use App\Models\Product;
use App\Models\Setting;
use App\Models\Suggestion;
use Dotenv\Validator;
use Illuminate\Http\Request;
use JWTAuth;

class DataController extends Controller
{
    public function notifications()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $rows = Notification::where('user_id', $user->id)->orderByDesc('id')->paginate(10);
        return NotificationResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }

    public function countries()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        $rows = Country::all();
        $data = [];
        foreach ($rows as $row) {
            $arr['id'] = $row->id;
            $arr['name'] = $row->name[$lang];
            $data[] = $arr;
        }
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function settings()
    {
        $lang = \request()->header('Accept-Language', 'ar');
        $setting = Setting::first();
        $data['commission'] = $setting ? $setting->commission : '';
        $data['android_link'] = $setting ? $setting->android_link : '';
        $data['ios_link'] = $setting ? $setting->ios_link : '';
        $data['policy'] = $setting ? $setting->policy[$lang] : '';
        $data['about'] = $setting ? $setting->about[$lang] : '';
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function contact_us(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'name' => 'required',
            'mobile' => 'required',
            'email' => 'email|required',
            'message' => 'required',
        ]);
        if ($validator->passes()) {
            ContactUs::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.saved')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
    public function suggestion(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'reason' => 'required',
            'body' => 'required',

        ]);
        if ($validator->passes()) {
            Suggestion::create($request->all());
            return response()->json(['value' => true, 'data' => \Lang::get('data.saved')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }
    public function search(Request $request){
        $lang = $request->header('Accept-Language','ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(),[
            'search'=>'required'
        ]);
        if ($validator->passes()){
            $rows = Product::where("title","LIKE","%".$request['search']."%")->paginate(10);
            return ProductResource::collection($rows)->additional(['value' => true, 'code' => 200]);


        }else{
            return response()->json(['value'=>false,'msg'=>$validator->errors()->first()]);
        }
    }
    public function categories(Request $request){
        $lang = $request->header('Accept-Language','ar');
        \App::setLocale($lang);
        $rows = Category::where('parent_id',null)->paginate(10);
        return CategoriesResource::collection($rows)->additional(['value' => true, 'code' => 200]);

    }
}
