<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\ProductResource;
use App\Models\Comment;
use App\Models\Favourite;
use App\Models\Notification;
use App\Models\Product;
use App\Models\ProductImage;
use App\Models\Rate;
use App\Models\Report;
use App\Models\UserToken;
use App\User;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;
use JWTAuth;
use function GuzzleHttp\Promise\all;

class ProductsController extends Controller
{
    public function post(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'images' => 'required',
            'category_id' => 'required',
            'sub_category_id' => 'nullable',
            'title' => 'required',
            'country_id' => 'required|exists:countries,id',
            'description' => 'required',
        ]);
        if ($validator->passes()) {
            $product = new Product();

            $product['title'] = $request['title'];
            $product['category_id'] = $request['category_id'];
            $product['sub_category_id'] = $request['sub_category_id'];
            $product['country_id'] = $request['country_id'];
            $product['description'] = $request['description'];
            $product['user_id'] = $user->id;
            $product->save();
            $i = 1;
            if ($request['images']) {
                foreach ($request['images'] as $image) {
                    $filename = time() . $i . '.' . $image->getClientOriginalExtension();
                    $i++;
                    $image->move(public_path('images/products'), $filename);
                    $product_image = new ProductImage();
                    $product_image['product_id'] = $product->id;
                    $product_image['image'] = $filename;
                    $product_image->save();
                }
            }
            return response()->json(['value' => true, 'data' => $product->id]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function rate_product(Request $request){
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(),[
            'product_id'=>'required|exists:products,id',
            'rate'=>'required',
            'comment'=>'required',
        ]);
        if ($validator->passes()){
            Rate::create([
                'user_id'=>$user->id,
                'product_id'=>$request['product_id'],
                'rate'=>$request['rate'],
                'comment'=>$request['comment']
            ]);
            return  response()->json(['value'=>true,'data'=>\Lang::get('data.rated')]);
        }else{
            return  response()->json(['value'=>false,'msg'=>$validator->errors()->first()]);
        }
    }

    public function rate_person(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'rated_user_id' => 'required|exists:users,id',
            'rate' => 'required',
            'comment' => 'required',
        ]);
        if ($validator->passes()) {
            Rate::create([
                'user_id' => $user->id,
                'rated_user_id' => $request['rated_user_id'],
                'rate' => $request['rate'],
                'comment' => $request['comment']
            ]);
            return response()->json(['value' => true, 'data' => \Lang::get('data.rated')]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function update_product(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'product_id' => 'required|exists:products,id',
        ]);
        if ($validator->passes()) {
            $product = Product::find($request['product_id']);

            $product['title'] = $request['title'] ? $request['title'] : $product->title;
            $product['category_id'] = $request['category_id'] ? $request['category_id'] : $product->category_id;
            $product['sub_category_id'] = $request['sub_category_id'] ? $request['sub_category_id'] : $product->sub_category_id;
            $product['country_id'] = $request['country_id'] ? $request['country_id'] : $product->country_id;
            $product['lat'] = $request['lat'] ? $request['lat'] : $product->lat;
            $product['lng'] = $request['lng'] ? $request['lng'] : $product->lng;
            $product['year'] = $request['year'] ? $request['year'] : $product->year;
            $product['type'] = $request['type'] ? $request['type'] : $product->type;
            $product['size'] = $request['size'] ? $request['size'] : $product->size;
            $product['shape'] = $request['shape'] ? $request['shape'] : $product->shape;
            $product['contact_type'] = $request['contact_type'] ? $request['contact_type'] : $product->contact_type;
            $product['receive_notification'] = $request['receive_notification'] ? $request['receive_notification'] : $product->receive_notification;
            $product['show_mobile'] = $request['show_mobile'] ? $request['show_mobile'] : $product->show_mobile;
            $product->update();
            $i = 1;
            if ($request['images']) {

                ProductImage::whereProductId($request['product_id'])->delete();


                foreach ($request['images'] as $image) {
                    $filename = time() . $i . '.' . $image->getClientOriginalExtension();
                    $i++;
                    $image->move(public_path('images/products'), $filename);
                    $product_image = new ProductImage();
                    $product_image['product_id'] = $product->id;
                    $product_image['image'] = $filename;
                    $product_image->save();
                }
            }

            $data = new ProductResource($product);
            return response()->json(['value' => true, 'data' => $data]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function complete_product(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $validator = \Validator::make($request->all(), [
            'product_id' => 'required|exists:products,id',
            'lat' => 'required',
            'lng' => 'required',
            'year' => 'required',
            'type' => 'required',
            'size' => 'required',
            'shape' => 'required',
            'contact_type' => 'required|in:phone,chat,both',
            'receive_notification' => 'required|in:true,false',
            'show_mobile' => 'required|in:true,false',

        ]);
        if ($validator->passes()) {
            $product = Product::find($request['product_id']);
            $product['lat'] = $request['lat'];
            $product['lng'] = $request['lng'];
            $product['year'] = $request['year'];
            $product['type'] = $request['type'];
            $product['size'] = $request['size'];
            $product['shape'] = $request['shape'];
            $product['contact_type'] = $request['contact_type'];
            $product['receive_notification'] = $request['receive_notification'];
            $product['show_mobile'] = $request['show_mobile'];
            $product->update();

            $data = new ProductResource($product);
            return response()->json(['value' => true, 'data' => $data]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function single_product($id)
    {
        $product = Product::find($id);
        $data = new ProductResource($product);
        return response()->json(['value' => true, 'data' => $data]);
    }

    public function favourite_product($id)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $check = Favourite::where(['user_id' => $user->id, 'product_id' => $id])->first();
        if ($check) {
            $check->delete();
            return response()->json(['value' => true, 'data' => \Lang::get('data.un_favourite')]);
        } else {
            Favourite::create(['user_id' => $user->id, 'product_id' => $id]);
            $product = Product::find($id);
            $owner = User::find($product->user_id);
            $body_ar = "$user->username قام بإعجاب منتج $product->title  ";
            $body_en = " $user->username favorite your product $product->title ";
            $notification = new Notification();
            $notification['user_id'] = $owner->id;
            $notification['type'] = 'favourite';
            $notification['product_id'] = $product->id;
            $notification['body->ar'] = $body_ar;
            $notification['body->en'] = $body_en;
            $notification->save();

            $tokens = UserToken::where('user_id', $owner->id)->whereStatus('connected')->get();
            foreach ($tokens as $token) {


                if ($token->lang == 'ar') {
                    $title = $body_ar;
                    $body = $body_ar;
                } else {

                    $title = $body_en;
                    $body = $body_en;

                }

                $push = new PushNotification('fcm');


                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'favourite',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'favourite',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'favourite',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }


            }


            return response()->json(['value' => true, 'data' => \Lang::get('data.make_favourite')]);
        }

    }


    public function my_products()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $rows = Product::whereUserId($user->id)->paginate(10);
        return ProductResource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }

    public function my_favorites()
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }

        $rows = $user->favourite_products()->paginate(10);
        return ProductResource::collection($rows)->additional(['value' => true, 'code' => 200]);


    }

    public function report(Request $request)
    {
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'body' => 'required',
            'product_id' => 'required_without:comment_id',
            'comment_id' => 'required_without:product_id'
        ]);
        if ($validator->passes()) {
            Report::create([
                'user_id' => $user->id,
                'comment_id' => $request['comment_id'],
                'product_id' => $request['product_id'],
                'body' => $request['body']
            ]);
            return response()->json(['value' => true, 'data' => \Lang::get('data.reported')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function comment(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        $validator = \Validator::make($request->all(), [
            'comment' => 'required',
            'product_id' => 'required',
        ]);
        if ($validator->passes()) {
            Comment::create([
                'user_id' => $user->id,
                'product_id' => $request['product_id'],
                'comment' => $request['comment']
            ]);


            $product = Product::find($request['product_id']);
            $owner = User::find($product->user_id);
            $body_ar = "   $user->username قام بكتابة تعليق علي منتج $product->title  ";
            $body_en = " $user->username Commented on $product->title ";
            $notification = new Notification();
            $notification['user_id'] = $owner->id;
            $notification['type'] = 'comment';
            $notification['product_id'] = $product->id;
            $notification['body->ar'] = $body_ar;
            $notification['body->en'] = $body_en;
            $notification->save();

            $tokens = UserToken::where('user_id', $owner->id)->whereStatus('connected')->get();
            foreach ($tokens as $token) {


                if ($token->lang == 'ar') {
                    $title = $body_ar;
                    $body = $body_ar;
                } else {

                    $title = $body_en;
                    $body = $body_en;

                }

                $push = new PushNotification('fcm');


                if ($token->device_type == 'ios') {
                    $msg = [
                        'data' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'comment',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'notification' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'comment',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                } else {
                    $msg = [
                        'data' => [
                            'title_ar' => $body_ar,
                            'title_en' => $body_en,
                            'body_ar' => $body_ar,
                            'body_en' => $body_en,
                            'type' => 'comment',
                            'sound' => 'default',
                            'title' => $title,
                            'body' => $body,
                            'product_id' => $product->id,
                            'click_action' => 'FCM_PLUGIN_ACTIVITY',
                        ],
                        'priority' => 'high',
                    ];
                    $push->setMessage($msg)
                        ->setDevicesToken($token->token)
                        ->send();

                }


            }


            return response()->json(['value' => true, 'data' => \Lang::get('data.commented')]);

        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first()]);
        }
    }

    public function delete_product($id)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (!$user = JWTAuth::parseToken()->authenticate()) {
            return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
        }
        Product::destroy($id);
        return response()->json(['value'=>true,'data'=>\Lang::get('data.deleted')]);
    }
}
