<?php

namespace App\Http\Controllers\web;

use App\Http\Controllers\Controller;
use App\Http\Middleware\Lang;
use App\Mail\ResetPassword;
use App\Models\Category;
use App\Models\ContactUs;
use App\Models\Country;
use App\Models\NewsLetter;
use App\Models\Product;
use App\User;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class HomeController extends Controller
{
    public function change_language_web($lang)
    {
        if ($lang == 'en' || $lang == 'ar') {
            if (!\Session::has('language')) {
                \Session::put('language', $lang);
            } else {
                \Session::put('language', $lang);
            }


            //  to get ar or en from url of change lang
            $lang = substr(\Request::path(), 9);
            // if ar replace en and put previous url
            if ($lang == "ar") {
                return redirect()->to(str_replace(url('/en'), '', url()->previous()));
            } else {
                return redirect()->to($lang . str_replace(url('/'), '', url()->previous()));
            }

        } else {
            return redirect('/');
        }
    }

    public function home()
    {
        if (\Auth::check()) {
            return redirect()->route('home_categories');
        } else {
            $countries = Country::all();
            return view('web.home', compact('countries'));
        }

    }


    public function home_categories()
    {
        $rows = Product::orderByDesc('id')->paginate(20);
        $categories = Category::where('parent_id', null)->get();
        $countries = Country::all();
        return view('web.categories', compact('rows', 'categories', 'countries'));
    }

    public function category_filter(Request $request)
    {
        $categories_id = $request['categories'];
        $country_id = $request['country_id'];

        $rows = Product::orderByDesc('id');
        if (isset($categories_id) && count($categories_id)) {
            $rows = $rows->whereIn('category_id', $categories_id);
        }
        if (isset($country_id)) {
            $rows = $rows->where('country_id', $country_id);
        }
        $rows = $rows->get();
        $categories = Category::where('parent_id', null)->get();
        $countries = Country::all();
        return view('web.categories', compact('rows', 'categories', 'countries'));


    }

    public function search(Request $request)
    {
        $rows = Product::where('title', 'like', '%' . $request['search'] . "%")->orderByDesc('id')->get();
        $categories = Category::where('parent_id', null)->get();
        $countries = Country::all();
        return view('web.categories', compact('rows', 'categories', 'countries'));

    }

    public function about_us()
    {
        return view('web.about_us');
    }

    public function contact_us()
    {
        return view('web.contact_us');
    }

    public function post_contact_us(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required',
            'mobile' => 'required',
            'message' => 'required'
        ]);
        ContactUs::create($request->all());
        toast(\Lang::get('site.send_contact_us'), 'success');
        return back();
    }

    public function news_letter(Request $request)
    {
        $check = NewsLetter::whereEmail($request->email)->first();
        if ($check) {
            Alert::error(\Lang::get('site.email_exist'));
        } else {
            NewsLetter::create($request->all());
            Alert::success(\Lang::get('site.email_subscribe'));

        }
        return back();
    }
}
