<?php

namespace App\Http\Controllers\web;

use App\Http\Controllers\Controller;
use App\Mail\ResetPassword;
use App\Models\Bank;
use App\Models\BankTransfer;
use App\Models\Country;
use App\Models\Product;
use App\Models\Rate;
use App\Models\Setting;
use App\User;
use Illuminate\Http\Request;
use RealRashid\SweetAlert\Facades\Alert;

class UsersController extends Controller
{

    public function login(Request $request)
    {
        $request->validate([
            'username' => 'required',
            'password' => 'required'
        ]);


//
//        if (\Auth::attempt(['email'=>$request['username'],'password'=>$request['password']])){
//            dd('true');
//        }else{
//            dd('false');
//        }
//


        $check_email = checkEmail($request['username']);
        if ($check_email == true) {

            $auth = ['email' => $request->input('username'), 'password' => $request->input('password')];

        } else {

            $auth = ['username' => $request->input('username'), 'password' => $request->input('password')];

        }
        if (\Auth::attempt($auth)) {
            toast(\Lang::get('site.welcome'), 'success');
            return redirect()->route('home_categories');
        } else {
            Alert::error(\Lang::get('site.wrong_entries'), \Lang::get('site.wrong_email'));

            return redirect()->back();
        }

    }


    public function profile()
    {
        $user = \Auth::user();
        $countries = Country::all();
        return view('web.users.profile', compact('user', 'countries'));
    }

    public function update_profile(Request $request)
    {
        $request->validate([
            'username' => 'required|unique:users,username,' . \Auth::user()->id,
            'email' => 'email|required|unique:users,email,' . \Auth::user()->id,
            'mobile' => 'required|unique:users,mobile,' . \Auth::user()->id,
            'country_id' => 'required|exists:countries,id'
        ]);

        $user = \Auth::user();
        $user['mobile'] = $request['mobile'];
        $user['username'] = $request['username'];
        $user['email'] = $request['email'];
        $user['country_id'] = $request['country_id'];
        $user->update();
        toast(\Lang::get('site.updated'), 'success');
        return back();

    }

    public function change_old_password(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'old_password' => 'required',
            'new_password' => 'required|confirmed',
            'new_password_confirmation' => 'required',
        ], [
            'old_password.required' => \Lang::get('site.old_password_required'),
            'new_password.required' => \Lang::get('site.new_password_required'),
            'new_password.confirmed' => \Lang::get('site.new_password_confirmed'),
            'new_password_confirmation.confirmed' => \Lang::get('site.new_password_confirmation_required'),
        ]);
        if ($validator->passes()) {
            $user = \Auth::user();
            if (\Hash::check($request['old_password'], $user->password)) {
                $user->password = bcrypt($request['new_password']);
                $user->update();

                $title = \Lang::get('site.password_updated');
                $confirmButtonText = \Lang::get('site.done');
                return response()->json(['status' => 1, 'msg' => $title, 'title' => $title, 'confirm_text' => $confirmButtonText]);


            } else {
                $title = \Lang::get('site.un_matched_password');
                $confirmButtonText = \Lang::get('site.close');
                return response()->json(['status' => 1, 'msg' => $title, 'title' => $title, 'confirm_text' => $confirmButtonText]);
            }


        } else {
            $title = \Lang::get('site.error');
            $confirmButtonText = \Lang::get('site.close');
            return response()->json(['status' => 0, 'msg' => $validator->errors()->first(), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        }
    }

    public function advertisement()
    {
        $user = \Auth::user();
        $rows = Product::where('user_id', $user->id)->orderByDesc('id')->get();
        return view('web.users.advertisement', compact('user', 'rows'));
    }

    public function owner_profile($username)
    {
        $user = User::whereUsername($username)->first();
        $rows = Product::whereUserId($user->id)->orderByDesc('id')->get();
        return view('web.users.owner_profile', compact('user','rows'));
    }

    public function rate_user($username,Request $request){
        $request->validate([
            'rate'=>'required',
            'comment_required'
        ]);
        $user = User::whereUsername($username)->first();
        Rate::create([
            'rate'=>$request['rate'],
            'comment'=>$request['comment'],
            'rated_user'=>$user->id,
            'user_id'=>\Auth::user()->id,
        ]);
        toast(\Lang::get('site.rated'),'success');
        return back();
    }

    public function commission(){
        $banks = Bank::all();
        return view('web.users.commission',compact('banks'));
    }
    public function calc_commission(Request $request){
        $setting = Setting::first();
        $amount = $request['amount'] * $setting->commission / 100 ;
        return response()->json(['data'=>$amount]);
    }
    public function pay_commission(Request $request){
        $request->validate([
            'in_calc'=>'required',
            'image'=>'image|image',
            'bank_id'=>'required|exists:banks,id'
        ],[
            'in_calc.required'=>"Please enter amount you pay"
        ]);

        $transfer =  new BankTransfer();
        $transfer['user_id'] = \Auth::user()->id;
        $transfer['full_name'] = \Auth::user()->username;
        $transfer['amount'] = $request['in_calc'];
        $transfer['bank_id'] = $request['bank_id'];
        if ($request->hasFile('image')){
          $transfer->setImageAttribute();
        }
        $transfer->save();
        toast(\Lang::get('site.payment_successful'),'success');
        return back();
    }
    public function rate_product($id, Request $request)
    {
        $request->validate([
            'rate' => 'required',
            'comment'=>'required'
        ]);
        Rate::create([
            'rate' => $request['rate'],
            'comment' => $request['comment'],
            'product_id' => $id,
            'user_id' => \Auth::user()->id,
        ]);
        toast(\Lang::get('site.rated'),'success');
        return back();
    }

    public function forget_password(Request $request)
    {
        $request->validate([
            'email' => 'required'
        ]);
        $user = User::whereEmail($request['email'])->first();
        if ($user) {
            $user['code'] = rand(1111, 9999);
            $user->update();
            \Session::put('user_email', $request['email']);
            \Mail::to($request['email'])->send(new ResetPassword($user->code));
            $title = \Lang::get('site.done_success');
            $confirmButtonText = \Lang::get('site.done');
            return response()->json(['status' => 1, 'msg' => \Lang::get('site.code_sent'), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        } else {
            $title = \Lang::get('site.error');
            $confirmButtonText = \Lang::get('site.close');
            return response()->json(['status' => 0, 'msg' => \Lang::get('site.no_user_email'), 'title' => $title, 'confirm_text' => $confirmButtonText]);

        }
    }

    public function reset_code(Request $request)
    {
        $request->validate([
            'code1' => 'required',
            'code2' => 'required',
            'code3' => 'required',
            'code4' => 'required',
        ]);

        $email = \Session::get('user_email');
        $user = User::whereEmail($email)->first();
        $code = $request['code1'] . $request['code2'] . $request['code3'] . $request['code4'];
        if ($user->code == $code) {
            $title = \Lang::get('site.done_success');
            $confirmButtonText = \Lang::get('site.done');
            return response()->json(['status' => 1, 'msg' => \Lang::get('site.code_correct'), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        } else {
            $title = \Lang::get('site.error');
            $confirmButtonText = \Lang::get('site.close');
            return response()->json(['status' => 0, 'msg' => \Lang::get('site.code_incorrect'), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        }
    }

    public function change_password(Request $request)
    {
        $validator = \Validator::make($request->all(), [
            'new_password' => 'required|confirmed',
            'new_password_confirmation' => 'required',
            'email' => 'required'
        ]);
        if ($validator->passes()) {
            //    $email = \Session::get('user_email');
            $user = User::whereEmail($request['email'])->first();

            $user->password = bcrypt($request['new_password']);
            $user->update();
            $title = \Lang::get('site.done_success');
            $confirmButtonText = \Lang::get('site.done');
            return response()->json(['status' => 1, 'msg' => \Lang::get('site.password_updated'), 'title' => $title, 'confirm_text' => $confirmButtonText]);

        } else {
            $title = \Lang::get('site.error');
            $confirmButtonText = \Lang::get('site.close');
            return response()->json(['status' => 0, 'msg' => $validator->errors()->first(), 'title' => $title, 'confirm_text' => $confirmButtonText]);
        }
    }

    public function register(Request $request)
    {
        $request->validate([
            'username' => 'required|unique:users,username',
            'email' => 'required|email|unique:users,email',
            'mobile' => 'required|unique:users,mobile',
            'country_id' => 'required|exists:countries,id',
            'password' => 'required|confirmed|min:6',
            'password_confirmation' => 'required',
        ], [
            'username.required' => \Lang::get('site.username_required'),
            'username.unique' => \Lang::get('site.username_unique'),
            'email.required' => \Lang::get('site.email_required'),
            'email.unique' => \Lang::get('site.email_unique'),
            'email.email' => \Lang::get('site.email_email'),
            'mobile.required' => \Lang::get('site.mobile_required'),
            'mobile.unique' => \Lang::get('site.mobile_unique'),
            'country_id.required' => \Lang::get('site.country_required'),
            'country_id.exists' => \Lang::get('site.country_exists'),
            'password.required' => \Lang::get('site.password_required'),
            'password.confirmed' => \Lang::get('site.password_confirmation'),
            'password.min' => \Lang::get('site.password_min'),
            'agree.accepted' => \Lang::get('site.agree_accepted')
        ]);

        $user = new User();
        $user['username'] = $request['username'];
        $user['email'] = $request['email'];
        $user['mobile'] = $request['mobile'];
        $user['password'] = bcrypt($request['password']);
        $user['country_id'] = $request['country_id'];
        $user['type'] = 'user';
        $user['status'] = 'active';
        $user->save();
        \Auth::login($user);
        toast(\Lang::get('site.welcome'), 'success');
        return redirect()->route('home_categories');
    }


    public function logout()
    {
        \Auth::logout();
        return redirect()->route('home');
    }
}
