<?php

namespace App\Http\Resources;

use App\Models\Comment;
use App\Models\Favourite;
use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;

class ProductResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $lang =$request->header('Accept-Language','ar');
        \App::setLocale($lang);
        $favourite_status = false;
        if ($request->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }

            $check = Favourite::where(['user_id' => $user->id, 'product_id' => $this->id])->first();
            if ($check) {
                $favourite_status = true;
            } else {
                $favourite_status = false;
            }
        }


        return [
            'id' => $this->id,
            'title' => $this->title ? $this->title : '',
            'country_name' => $this->country->name[$lang],
            'description' => $this->description,
            'contact_type' => $this->contact_type,
            'receive_notification' => $this->receive_notification,
            'show_mobile' => $this->show_mobile,
            'lat' => $this->lat,
            'lng' => $this->lng,
            'size' => $this->size,
            'shape' => $this->shape,
            'year' => $this->year,
            'type' => $this->type,
            'favourite_status' => $favourite_status,
            'rate' => getProductRate($this->id),
            'created_time'=>Carbon::parse($this->created_at)->toDateString(),
            'owner_id'=>$this->user ? (integer)$this->user->id : 0,
            'owner_username'=>$this->user ? $this->user->username : '',
            'owner_image'=>$this->image ? asset('images/users/' . $$this->user->image) : '',
            'comments'=>CommentsResource::collection($this->comments),
            'images'=>ProductImageResource::collection($this->images)


        ];
    }
}
